@@ -11,7 +11,6 @@
   email:     eisfuchs@tigress.com
 */
 
-
 #ifndef IGNORELISTVIEWITEM_H
 #define IGNORELISTVIEWITEM_H
 
@@ -25,21 +24,19 @@
 
 class IgnoreListViewItem : public KListViewItem
 {
-  public:
-    IgnoreListViewItem(QListView* parent,QString name,int flags);
-    ~IgnoreListViewItem();
+    public:
+        IgnoreListViewItem(QListView* parent,QString name,int flags);
+        ~IgnoreListViewItem();
 
-    void setFlag(int flag,bool active);
-    bool getFlag(int flag) { return flags & flag; };
-    int getFlags() { return flags; };
-    IgnoreListViewItem* itemBelow();
+        void setFlag(int flag,bool active);
+        bool getFlag(int flag) { return m_flags & flag; };
+	QString getName() { return text(0); };
+	void setName(QString name) { setText(0, name); };
+        int getFlags() { return m_flags; };
+        IgnoreListViewItem* itemBelow();
 
-  protected:
-    void setFlags(int flags);
-    QString yes;
-    QString no;
-
-    int flags;
+        void setFlags(int flags);
+    protected:
+        int m_flags;
 };
-
 #endif
